@@ -213,10 +213,14 @@ def check_estimate_effects(model_dat, alpha, do_print=True):
     """estimate structural model given alpha in model_dat"""
 
     mx_hat, my_hat, sse_hat = estimate_snn(model_dat, alpha, do_print)
+    mx_hat[model_dat["idx"] == 0] = float("NaN")
+    my_hat[model_dat["idy"] == 0] = float("NaN")
 
     ex_hat, ey_hat = utils.total_effects_alg(
         mx_hat, my_hat, model_dat["edx"], model_dat["edy"]
     )
+    ex_hat[model_dat["edx"] == 0] = float("NaN")
+    ey_hat[model_dat["edy"] == 0] = float("NaN")
     direct_hat = utils.directvec(mx_hat, my_hat, model_dat["idx"], model_dat["idy"])
 
     hessian_hat = sse_hess_alg(direct_hat, model_dat, alpha)
@@ -477,6 +481,9 @@ def estimate_effects(model_dat, estimate_input):
         model_dat["yvars"],
         model_dat["final_var"],
     )
+    # final_ind = list(model_dat["yvars"]).index(model_dat["final_var"])
+    # eyx_hat[model_dat["edx"] == 0] = float("NaN")
+    # eyy_hat[model_dat["edy"][final_ind] == 0] = float("NaN")
 
     estimate_dat = {
         "direct_hat": direct_hat,
@@ -598,6 +605,12 @@ def estimate_models(m, xdat, mean_theo, estimate_input):
         estimate_dat["biases"] = biases
         estimate_dat["biases_std"] = biases_std
 
+    # set missing edges to NaN
+    estimate_dat["mx_hat"][model_dat["idx"] == 0] = float("NaN")
+    estimate_dat["my_hat"][model_dat["idy"] == 0] = float("NaN")
+    estimate_dat["mx_hat_std"][model_dat["idx"] == 0] = float("NaN")
+    estimate_dat["my_hat_std"][model_dat["idy"] == 0] = float("NaN")
+
     return estimate_dat
 
 
@@ -842,8 +855,8 @@ def compute_mediation_std(ex_hat_std, ey_hat_std, eyx, eyy, yvars, final_var):
     eyj_hat_std_mat = np.tile(eyj_hat_std, (ndim, 1))  # (ndim x ndim)
 
     # column sums of mediation matrices
-    x_colsum = np.sum(eyx, axis=0)
-    y_colsum = np.sum(eyy, axis=0)
+    x_colsum = np.nansum(eyx, axis=0)
+    y_colsum = np.nansum(eyy, axis=0)
     # normed mediation matrices by division by column sums,
     # zero sum for varaibles w/o effect on others
     # substituted by nan to avoid false interpretation
@@ -946,6 +959,8 @@ def total_effects_std(direct_hat, vcm_direct_hat, model_dat):
     # set main diag of ey_std to 0, since edy diag is 1 instead of 0
     np.fill_diagonal(ey_std, 0)
 
+    ex_std[model_dat["edx"] == 0] = float("NaN")
+    ey_std[model_dat["edy"] == 0] = float("NaN")
     return ex_std, ey_std
 
 
